Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BlockDeviceInfo ¶
type BlockDeviceInfo struct {
Blockdevices []Blockdevice `json:"blockdevices"`
}
BlockDeviceInfo exposes the json output of lsblk:"blockdevices"
type Blockdevice ¶
type Blockdevice struct {
Name string `json:"name"` //block device name
Majmin string `json:"maj:min"` //major and minor block device number
Rm string `json:"rm"` //is device removable
Size string `json:"size"` //size of device
Ro string `json:"ro"` //is device read-only
Type string `json:"type"` //is device disk or partition
Mountpoint string `json:"mountpoint"` //block device mountpoint
Children []Blockdevice `json:"children,omitempty"` //Blockdevice ...
}
Blockdevice has block disk fields
type HostDirSBA ¶
type HostDirSBA struct {
StorageBackendAdaptor
HostDir string `json:"hostDir"`
}
HostDirSBA contains the generic options that apply to all the HostDirStorageBackendAdaptors (K8s CRD yaml)
type StorageBackendAdaptor ¶
type StorageBackendAdaptor struct {
NodeFilter string `json:"nodeFilter"`
MaxAllocationSize string `json:"maxAllocationSize"`
}
StorageBackendAdaptor contains the generic options that apply to all the StorageBackendAdaptors (K8s CRD yaml)
Click to show internal directories.
Click to hide internal directories.