Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckError ¶
func CheckError(err error)
CheckError prints err to stderr and exits with code 1 if err is not nil. Otherwise, it is a no-op.
func NewCmdStart ¶
NewCmdStart creates start command for maya-apiserver
func NewCommand ¶
NewCommand creates the `maya-apiserver` command and its nested children.
Types ¶
type CmdStartOptions ¶
type CmdStartOptions struct {
BindAddr string
LogLevel string
ConfigPath string
ShutdownCh <-chan struct{}
// contains filtered or unexported fields
}
CmdStartOptions is a cli implementation that runs a maya apiserver. The command will not end unless a shutdown message is sent on the ShutdownCh. If two messages are sent on the ShutdownCh it will forcibly exit.
Click to show internal directories.
Click to hide internal directories.